# Project Specific Styling

For information, there are currently 2 project css/scss files for styling, this is in preparation for future scss migration:

## - project.scss
Used for the Arches-HER landing page. There are 3 other required related files: _project-breakpoints.scss, _project-functions.scss and _project-variables.scss.

## - project.css
Used for the rest of the site where the project.css is imported by the base.htm template.